@@ -11,6 +11,8 @@ from countergen.tools.math_utils import geometric_mean, mean
 
 @define
 class AveragePerformancePerCategory(StatsAggregator):
+    """Compute the average performance for each category."""
+
     use_geometric_mean: bool = False
 
     def __call__(self, performances: Results) -> Mapping[Category, float]:
@@ -47,7 +49,7 @@ class Stats:
     uncertainty_2sig: float
 
     @classmethod
-    def from_seq(cls, s: Sequence[float]):
+    def from_seq(cls, s: Sequence[float]) -> "Stats":
         assert s, "empty seq"
         a = np.array(s)
         uncertainty_2sig = 2 * a.std() / np.sqrt(len(s))
@@ -56,7 +58,7 @@ class Stats:
 
 @define
 class PerformanceStatsPerCategory(StatsAggregator):
-    """Compute mean and uncertainty over mean."""
+    """Compute performance mean and the 2 sigma uncertainty over mean for each category."""
 
     def __call__(self, performances: Results) -> Mapping[Category, Stats]:
         performances_per_category: DefaultDict[Category, List[Performance]] = defaultdict(lambda: [])
@@ -123,6 +125,3 @@ class AverageDifference(StatsAggregator):
     def load_aggregation(self, file: TextIO) -> float:
         lines = file.readlines()
         return float(lines[1])
-
-    def display(self, aggregates: Mapping[str, float]):
-        raise NotImplementedError()
