@@ -5,7 +5,7 @@ from typing import Any, Callable, Dict, Iterable, Mapping, Optional, Sequence, T
 from tqdm import tqdm  # type: ignore
 import openai
 
-from countergen.config import OPENAI_API_KEY
+from countergen.config import OPENAI_API_BASE, OPENAI_API_KEY
 
 T = TypeVar("T")
 
@@ -41,8 +41,15 @@ def estimate_paraphrase_length(text: str):
     return len(text) // average_token_length + safety_margin
 
 
-def set_and_check_oai_key(key: Optional[str] = OPENAI_API_KEY):
+def set_and_check_oai_key(key: Optional[str] = OPENAI_API_KEY, base: str = OPENAI_API_BASE):
+    """Set the key (and the base) of the openai api.
+
+    Default arguments are the ones from the config.
+
+    Checks that the key is not None."""
     if key is None:
         raise RuntimeError(
             "Please provide openai key to use its api! Use `countergen.config.OPENAI_API_KEY = YOUR_KEY`"
         )
+    openai.api_key = key
+    openai.api_base = base
